import { __read, __spread } from "tslib";
import { getCurrentHub } from '@sentry/core';
import { app, powerMonitor, screen, } from 'electron';
/** Electron integration that cleans up the event. */
var Electron = /** @class */ (function () {
    function Electron() {
        /**
         * @inheritDoc
         */
        this.name = Electron.id;
    }
    /**
     * @inheritDoc
     */
    Electron.prototype.setupOnce = function () {
        var _this = this;
        this._instrumentBreadcrumbs('app', app);
        app.once('ready', function () {
            // We can't access these until 'ready'
            _this._instrumentBreadcrumbs('Screen', screen);
            _this._instrumentBreadcrumbs('PowerMonitor', powerMonitor);
        });
        app.on('web-contents-created', function (_, contents) {
            // SetImmediate is required for contents.id to be correct
            // https://github.com/electron/electron/issues/12036
            setImmediate(function () {
                if (contents.isDestroyed()) {
                    return;
                }
                var options = getCurrentHub().getClient().getOptions();
                var customName = options.getRendererName && options.getRendererName(contents);
                _this._instrumentBreadcrumbs(customName || "WebContents[" + contents.id + "]", contents, [
                    'dom-ready',
                    'load-url',
                    'destroyed',
                ]);
            });
        });
    };
    /**
     * Hooks into the Electron EventEmitter to capture breadcrumbs for the
     * specified events.
     */
    Electron.prototype._instrumentBreadcrumbs = function (category, emitter, events) {
        if (events === void 0) { events = []; }
        var emit = emitter.emit.bind(emitter);
        emitter.emit = function (event) {
            var args = [];
            for (var _i = 1; _i < arguments.length; _i++) {
                args[_i - 1] = arguments[_i];
            }
            if (events.length === 0 || events.indexOf(event) > -1) {
                var breadcrumb = {
                    category: 'electron',
                    message: category + "." + event,
                    timestamp: new Date().getTime() / 1000,
                    type: 'ui',
                };
                var self_1 = getCurrentHub().getIntegration(Electron);
                if (self_1) {
                    getCurrentHub().addBreadcrumb(breadcrumb);
                }
            }
            return emit.apply(void 0, __spread([event], args));
        };
    };
    /**
     * @inheritDoc
     */
    Electron.id = 'Electron';
    return Electron;
}());
export { Electron };
//# sourceMappingURL=electron.js.map